<?php
// -----------------------------------------------------------------------------
// $Id: search.php 110 2018-01-02 16:05:01Z Raoul $
//
// Copyright (C) 2018 Raoul Proença
// License: GNU GPL version 3 (see copying.txt file)
// Website: http://www.gnew.xyz/
// -----------------------------------------------------------------------------
// This program is free software: you can redistribute it and/or modify it under
// the terms of the GNU General Public License as published by the Free Software
// Foundation, either version 3 of the License, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along with
// this program. If not, see <http://www.gnu.org/licenses/>.
// -----------------------------------------------------------------------------

include('./../includes/common.php');

page_header($lang['COMMENTS_SEARCH']);

// Comments in news enabled?
if ($settings['news_commenting'] == 0)
{
    error_template($lang['ERROR_COMMENTING_DISABLED']);
}
elseif (isset($_GET['search']))
{
    // Clean and format string
    $pattern = array('`[ ]+`', '`[?]+`');
    $replace = array(' ', '?');
    $str = preg_replace($pattern, $replace, trim($_GET['search']));
    $str = utf8_entities(stripslashes($str));

    $search = '';
    $length = strlen($str);
    for ($i = 0; $i < $length; $i++)
    {
        // Valid search string: at least 3 characters long (see below)
        // and composed of letters (accented or not), digits or - and _ characters
        if (preg_match('`[a-z0-9_\-&#;]`i', $str{$i}))
        {
            $search .= $str{$i};
        }
        elseif ($str{$i} == ' ')
        {
            $search .= '%';
        }
        elseif ($str{$i} == '?')
        {
            $search .= '_';
        }
        else
        {
            $search .= '';
        }
    }

    // HTML entities
    preg_match_all('`&[^;\s]+;`', $search, $entities);
    $num_entities = count($entities[0]);
    $offset = 0;
    for ($i = 0; $i < $num_entities; $i++)
    {
        $offset += strlen($entities[0][$i]);
    }

    // Check string
    if (!empty($search) && (strlen($search) - $offset + $num_entities) >= 3)
    {
        if (empty($_GET['match']) || !preg_match('`^(comment_subject|comment_text)$`', $_GET['match']))
        {
            $_GET['match'] = 'comment_subject';
        }
        if (empty($_GET['news_id']) || !string_is_int($_GET['news_id']))
        {
            error_template($lang['ERROR_NO_DATA']);
        }
        else
        {
            $num_comments = 0;
            $template->set_file('search', 'comments/search.htpl');
            $template->set_block('search', 'COMMENTS_BLOCK', 'comments');
            $sql->query('SELECT t1.comment_id, t1.story_id, t1.news_id, t1.user_id, t1.comment_subject, t1.comment_text, t1.comment_creation, t1.comment_edition, t1.edition_id, t1.edition_name, t2.user_avatar, t2.user_name, t2.user_signature
                         FROM ' . TABLE_COMMENTS . ' AS t1
                         INNER JOIN ' . TABLE_USERS . ' AS t2
                                    ON t2.user_id = t1.user_id
                         WHERE t1.news_id = \'' . $_GET['news_id'] . '\'
                         AND t1.comment_active = \'1\'
                         AND LOWER(t1.' . $_GET['match'] . ') LIKE \'%' . strtolower($search) . '%\'
                         ORDER BY t1.comment_creation DESC
                         LIMIT ' . ($settings['search_limit'] + 1));
            while ($table_comments = $sql->fetch())
            {
                // Count comments
                $num_comments++;

                // Temporary tags to delimit search string - only elements outside HTML tags are highlighted
                $comment_subject = '<!-- GNEW_TEMP -->' . $table_comments['comment_subject'] . '<!-- GNEW_TEMP -->';
                $comment_text = '<!-- GNEW_TEMP -->' . $table_comments['comment_text'] . '<!-- GNEW_TEMP -->';

                $elements = explode('%', $search);
                $num_elements = count($elements);
                for ($i = 0; $i < $num_elements; $i++)
                {
                    // Highlight elements
                    if ($_GET['match'] == 'comment_subject')
                    {
                        $comment_subject = preg_replace('`([^&#])(' . $elements[$i] . ')([^;])?(?=[^>]*<)`i', '\\1<span class="new">\\2</span>\\3', $comment_subject);
                    }
                    if ($_GET['match'] == 'comment_text')
                    {
                        $comment_text = preg_replace('`([^&#])(' . $elements[$i] . ')([^;])?(?=[^>]*<)`i', '\\1<span class="new">\\2</span>\\3', $comment_text);
                    }
                }

                // Remove temporary tags
                $comment_subject = str_replace('<!-- GNEW_TEMP -->', '', $comment_subject);
                $comment_text = str_replace('<!-- GNEW_TEMP -->', '', $comment_text);

                if ($table_comments['comment_edition'])
                {
                    $comment_edited = sprintf($lang['EDITED_BY'], $table_comments['edition_id'], $table_comments['edition_name'], format_date($table_comments['comment_edition']));
                }
                else
                {
                    $comment_edited = '';
                }
                if (!empty($table_comments['user_signature']))
                {
                    $user_signature = '<br />&#45;&#45;<br />' . $table_comments['user_signature'];
                }
                else
                {
                    $user_signature = '';
                }
                $comment_text = undo_escape_sequences($comment_text);
                $comment_text = cut_text($comment_text, './../comments/index.php?news_id=' . $table_comments['news_id'] . '&amp;story_id=' . $table_comments['story_id'] . '&amp;comment_id=' . $table_comments['comment_id']);
                $template->set_var(array('COMMENT_ID' => $table_comments['comment_id'],
                                         'COMMENT_EDITED' => $comment_edited,
                                         'COMMENT_POSTED' => sprintf($lang['POSTED_BY'], $table_comments['user_id'], $table_comments['user_name'], format_date($table_comments['comment_creation'])),
                                         'COMMENT_SUBJECT' => $comment_subject,
                                         'COMMENT_TEXT' => $comment_text,
                                         'NEWS_ID' => $table_comments['news_id'],
                                         'STORY_ID' => $table_comments['story_id'],
                                         'USER_AVATAR' => $table_comments['user_avatar'],
                                         'USER_SIGNATURE' => $user_signature));
                $template->parse('COMMENTS_BLOCK', 'comments', true);
                $comments_exist = true;
            }
            if ($num_comments > $settings['search_limit'])
            {
                error_template(sprintf($lang['ERROR_SEARCH_LIMIT'], $settings['search_limit']));
            }
            else
            {
                if (isset($comments_exist))
                {
                        $template->set_var('HEADER_SEARCH', sprintf($lang['HEADER_SEARCH'], $str, $num_comments));
                        $template->parse('search', null, false, array(TABLE_COMMENTS, TABLE_USERS));
                }
                else
                {
                    error_template($lang['SEARCH_HELP']);
                }
            }
        }
    }
    else
    {
        error_template($lang['ERROR_BAD_SEARCH']);
    }
}
else
{
    error_template($lang['ERROR_NO_DATA']);
}

page_footer();

?>