<?php
// -----------------------------------------------------------------------------
// $Id: search.php 110 2018-01-02 16:05:01Z Raoul $
//
// Copyright (C) 2018 Raoul Proença
// License: GNU GPL version 3 (see copying.txt file)
// Website: http://www.gnew.xyz/
// -----------------------------------------------------------------------------
// This program is free software: you can redistribute it and/or modify it under
// the terms of the GNU General Public License as published by the Free Software
// Foundation, either version 3 of the License, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along with
// this program. If not, see <http://www.gnu.org/licenses/>.
// -----------------------------------------------------------------------------

include('./../includes/common.php');

page_header($lang['POSTS_SEARCH']);

if (isset($_GET['search']))
{
    // Clean and format string
    $pattern = array('`[ ]+`', '`[?]+`');
    $replace = array(' ', '?');
    $str = preg_replace($pattern, $replace, trim($_GET['search']));
    $str = utf8_entities(stripslashes($str));

    $search = '';
    $length = strlen($str);
    for ($i = 0; $i < $length; $i++)
    {
        // Valid search string: at least 3 characters long (see below)
        // and composed of letters (accented or not), digits or - and _ characters
        if (preg_match('`[a-z0-9_\-&#;]`i', $str{$i}))
        {
            $search .= $str{$i};
        }
        elseif ($str{$i} == ' ')
        {
            $search .= '%';
        }
        elseif ($str{$i} == '?')
        {
            $search .= '_';
        }
        else
        {
            $search .= '';
        }
    }

    // HTML entities
    preg_match_all('`&[^;\s]+;`', $search, $entities);
    $num_entities = count($entities[0]);
    $offset = 0;
    for ($i = 0; $i < $num_entities; $i++)
    {
        $offset += strlen($entities[0][$i]);
    }

    // Check string
    if (!empty($search) && (strlen($search) - $offset + $num_entities) >= 3)
    {
        if (empty($_GET['match']) || !preg_match('`^(post_subject|post_text)$`', $_GET['match']))
        {
            $_GET['match'] = 'post_subject';
        }
        if (empty($_GET['category_id']) || !string_is_int($_GET['category_id']))
        {
            error_template($lang['ERROR_NO_DATA']);
        }
        else
        {
            $num_posts = 0;
            // Only administrators can search in private categories
            if ($users['user_level'] < 4)
            {
                $clause = ' AND t2.category_level IN (\'3\', \'4\')';
            }
            else
            {
                $clause = ' AND t2.category_level IN (\'0\', \'3\', \'4\')';
            }
            $template->set_file('search', 'posts/search.htpl');
            $template->set_block('search', 'POSTS_BLOCK', 'posts');
            $sql->query('SELECT t1.thread_id, t1.category_id, t1.user_id, t1.post_subject, t1.post_text, t1.post_creation, t1.post_edition, t1.edition_id, t1.edition_name, t3.user_avatar, t3.user_name, t3.user_posts, t3.user_signature, t3.user_creation
                         FROM ' . TABLE_POSTS . ' AS t1
                         INNER JOIN ' . TABLE_CATEGORIES . ' AS t2
                                    ON t2.category_id = t1.category_id' . $clause . '
                         INNER JOIN ' . TABLE_USERS . ' AS t3
                                    ON t3.user_id = t1.user_id
                         WHERE t1.category_id = \'' . $_GET['category_id'] . '\'
                         AND LOWER(t1.' . $_GET['match'] . ') LIKE \'%' . strtolower($search) . '%\'
                         ORDER BY t1.post_creation DESC
                         LIMIT ' . ($settings['search_limit'] + 1));
            while ($table_posts = $sql->fetch())
            {
                // Count posts
                $num_posts++;

                // Temporary tags to delimit search string - only elements outside HTML tags are highlighted
                $post_subject = '<!-- GNEW_TEMP -->' . $table_posts['post_subject'] . '<!-- GNEW_TEMP -->';
                $post_text = '<!-- GNEW_TEMP -->' . $table_posts['post_text'] . '<!-- GNEW_TEMP -->';

                $elements = explode('%', $search);
                $num_elements = count($elements);
                for ($i = 0; $i < $num_elements; $i++)
                {
                    // Highlight elements
                    if ($_GET['match'] == 'post_subject')
                    {
                        $post_subject = preg_replace('`([^&#])(' . $elements[$i] . ')([^;])?(?=[^>]*<)`i', '\\1<span class="new">\\2</span>\\3', $post_subject);
                    }
                    if ($_GET['match'] == 'post_text')
                    {
                        $post_text = preg_replace('`([^&#])(' . $elements[$i] . ')([^;])?(?=[^>]*<)`i', '\\1<span class="new">\\2</span>\\3', $post_text);
                    }
                }

                // Remove temporary tags
                $post_subject = str_replace('<!-- GNEW_TEMP -->', '', $post_subject);
                $post_text = str_replace('<!-- GNEW_TEMP -->', '', $post_text);

                if ($table_posts['post_edition'])
                {
                    $post_edited = sprintf($lang['EDITED_BY'], $table_posts['edition_id'], $table_posts['edition_name'], format_date($table_posts['post_edition']));
                }
                else
                {
                    $post_edited = '';
                }
                if (!empty($table_posts['user_signature']))
                {
                    $user_signature = '<br />&#45;&#45;<br />' . $table_posts['user_signature'];
                }
                else
                {
                    $user_signature = '';
                }
                $post_text = undo_escape_sequences($post_text);
                $post_text = cut_text($post_text, './../posts/read.php?category_id=' . $table_posts['category_id'] . '&amp;thread_id=' . $table_posts['thread_id']);
                $template->set_var(array('CATEGORY_ID' => $table_posts['category_id'],
                                         'POST_EDITED' => $post_edited,
                                         'POST_POSTED' => format_date($table_posts['post_creation']),
                                         'POST_SUBJECT' => $post_subject,
                                         'POST_TEXT' => $post_text,
                                         'THREAD_ID' => $table_posts['thread_id'],
                                         'USER_AVATAR' => $table_posts['user_avatar'],
                                         'USER_CREATION' => format_date($table_posts['user_creation']),
                                         'USER_ID' => $table_posts['user_id'],
                                         'USER_NAME' => $table_posts['user_name'],
                                         'USER_POSTS' => $table_posts['user_posts'],
                                         'USER_SIGNATURE' => $user_signature));
                $template->parse('POSTS_BLOCK', 'posts', true);
                $posts_exist = true;
            }
            if ($num_posts > $settings['search_limit'])
            {
                error_template(sprintf($lang['ERROR_SEARCH_LIMIT'], $settings['search_limit']));
            }
            else
            {
                if (isset($posts_exist))
                {
                        $template->set_var('HEADER_SEARCH', sprintf($lang['HEADER_SEARCH'], $str, $num_posts));
                        $template->parse('search', null, false, array(TABLE_CATEGORIES, TABLE_POSTS, TABLE_USERS));
                }
                else
                {
                    error_template($lang['SEARCH_HELP']);
                }
            }
        }
    }
    else
    {
        error_template($lang['ERROR_BAD_SEARCH']);
    }
}
else
{
    error_template($lang['ERROR_NO_DATA']);
}

page_footer();

?>